Ask chatGPT to summarise each cluster based on the samples metadata.
run_gpt(
obj = NULL,
reduction = "UMAP",
label_var = "label",
cluster_var = "seurat_clusters",
terms_per_cluster = 3,
force_new = FALSE,
return_all_results = FALSE,
verbose = TRUE
)Single-cell data object.
Name of the reduction to use (case insensitive).
Which cell metadata column to input to NLP analysis.
Which cell metadata column to use to identify which cluster each cell is assigned to.
The maximum number of words to return per cluster.
If NLP results are already detected the metadata,
set force_new=TRUE to replace them with new results.
Whether to return just the obj
with updated metadata (TRUE),
or all intermediate results (FALSE).
Whether to print messages.
The input object with GPT summary added to metadata, or if
return_all_results=TRUE, a list with the object and intermediate
results.